const API_URL = 'https://onereview.org/api/websites';
const WEBAPP_URL = 'https://onereview.org';

const ALERT_FREQUENCY_DAYS = 7;
const DEFAULT_SETTINGS = {
  riskThreshold: 60, // Medium Risk (3 * 20)
  indicatorThreshold: 40, // Low Risk (2 * 20)
  enableLiveChecks: true
};

// Cache for settings to avoid frequent storage reads
let currentSettings = { ...DEFAULT_SETTINGS };
let lastCheckedDomain = '';

// Function to extract domain from URL
function extractDomain(url) {
  if (!url) return null;
  try {
    const urlObj = new URL(url);
    return urlObj.hostname.replace(/^www\./, '');
  } catch (e) {
    console.error('Error extracting domain:', e);
    return null;
  }
}

// Function to check if we should show alert for this domain
async function shouldShowAlert(domain) {
  if (!domain) return false;
  try {
    const { alerts = {} } = await chrome.storage.local.get('alerts');
    const lastAlertTime = alerts[domain];
    if (!lastAlertTime) return true;
    return (Date.now() - lastAlertTime) / (1000 * 60 * 60 * 24) >= ALERT_FREQUENCY_DAYS;
  } catch (error) {
    console.error('Error checking alert history:', error);
    return false; // Fail safe - don't show alert if there's an error
  }
}

// Function to record alert shown
async function recordAlertShown(domain) {
  if (!domain) return;
  try {
    const { alerts = {} } = await chrome.storage.local.get('alerts');
    alerts[domain] = Date.now();
    await chrome.storage.local.set({ alerts });
  } catch (error) {
    console.error('Error recording alert:', error);
  }
}

// Function to check website risk
async function checkWebsiteRisk(domain) {
  if (!domain) return null;
  try {
    const url = new URL(API_URL);
    url.searchParams.append('query', encodeURIComponent(domain));

    const response = await fetch(url);
    if (!response.ok) {
      throw new Error(`HTTP error! status: ${response.status}`);
    }
    const result = await response.json();
    return result.data?.[0] || null;
  } catch (error) {
    console.error('Error checking website risk:', error);
    return null;
  }
}

// Function to show notifications
async function showNotification(tabId, type, website) {
  if (!tabId || !website || !type) return;
  try {
    await chrome.tabs.sendMessage(tabId, { type, website });
  } catch (error) {
    console.log(`Error showing ${type}:`, error);
  }
}

// Function to load settings
async function loadSettings() {
  try {
    const settings = await chrome.storage.sync.get(Object.keys(DEFAULT_SETTINGS));
    currentSettings = {
      riskThreshold: settings.riskThreshold ?? DEFAULT_SETTINGS.riskThreshold,
      indicatorThreshold: settings.indicatorThreshold ?? DEFAULT_SETTINGS.indicatorThreshold,
      enableLiveChecks: settings.enableLiveChecks ?? DEFAULT_SETTINGS.enableLiveChecks
    };
    console.debug('Settings loaded:', currentSettings);
  } catch (error) {
    console.error('Error loading settings:', error);
    currentSettings = { ...DEFAULT_SETTINGS };
  }
}

// Function to handle website data and show alerts/indicators
async function handleWebsiteData(tabId, website) {
  if (!tabId || !website) return;

  const { risk_score, domain } = website;
  const { riskThreshold, indicatorThreshold } = currentSettings;

  // Show alert if risk score is above threshold and not shown recently
  if (risk_score >= riskThreshold && await shouldShowAlert(domain)) {
    await recordAlertShown(domain);
    await showNotification(tabId, 'showRiskAlert', website);
  }

  // Show indicator if risk score is above indicator threshold
  if (risk_score >= indicatorThreshold) {
    await showNotification(tabId, 'showRiskIndicator', website);
  }
}

// Function to handle tab updates
async function handleTabUpdate(tabId, changeInfo, tab) {
  // Only process complete loads of new URLs
  if (changeInfo.status !== 'complete' || !tab.url) {
    return;
  }

  // Ensure settings are loaded
  if (!currentSettings) {
    await loadSettings();
  }

  const domain = extractDomain(tab.url);
  if (!domain || domain === lastCheckedDomain) return;

  lastCheckedDomain = domain;

  // Skip if live checks are disabled
  if (!currentSettings.enableLiveChecks) {
    console.debug('Live checks disabled, skipping:', domain);
    return;
  }

  const website = await checkWebsiteRisk(domain);
  if (website) {
    await handleWebsiteData(tabId, website);
  }
}

// Function to initialize extension
async function initializeExtension() {
  console.log('Initializing extension');
  await loadSettings();
  console.log('Settings loaded');
  chrome.tabs.onUpdated.addListener(handleTabUpdate);
  console.log('Tab update listener added');
}

// Message handlers
const messageHandlers = {
  getSettings: (request, sender, sendResponse) => {
    sendResponse(currentSettings);
    return true;
  },
  settingsUpdated: async (request, sender, sendResponse) => {
    await loadSettings();
    sendResponse({ success: true });
    return true;
  },
  openSettings: () => {
    chrome.runtime.openOptionsPage();
    return true;
  },
  checkCurrentTab: async () => {
    try {
      const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });
      if (tab?.url) {
        const domain = extractDomain(tab.url);
        if (domain) {
          const website = await checkWebsiteRisk(domain);
          if (website) {
            await handleWebsiteData(tab.id, website);
          }
        }
      }
    } catch (error) {
      console.error('Error checking current tab:', error);
    }
    return true;
  }
};

// Listen for messages
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  const handler = messageHandlers[request.type];
  return handler ? handler(request, sender, sendResponse) : false;
});

// Installation handling
async function handleInstallation(details) {
  try {
    const { installationId } = await chrome.storage.local.get('installationId');
    if (installationId && details.reason === 'update') {
      console.debug('Extension updated, keeping ID:', installationId);
      console.debug('Updated from version:', details.previousVersion);
      return;
    }
    
    if (!installationId && details.reason === 'install') {
      const newId = `or_${Date.now()}_${Math.random().toString(36).slice(2, 11)}`;
      await chrome.storage.local.set({ installationId: newId });
      console.debug('New installation ID created:', newId);
    }
  } catch (error) {
    console.error('Error handling installation:', error);
  }
}

// Initialize extension
initializeExtension();
// Handle installation/updates
chrome.runtime.onInstalled.addListener(handleInstallation); 