const API_URL = 'https://onereview.org/api/websites';
const WEBAPP_URL = 'https://onereview.org';

// Function to create and show the overlay
function showRiskOverlay(website) {
  // Remove any existing overlay
  removeOverlay();

  // Determine risk level
  const riskLevel = getRiskLevel(website.risk_score);

  // Format review content
  let reviewContent = '';
  
  // Add scam risk warning if applicable
  if (website.scam_adviser_score && website.scam_adviser_score < 80) {
    reviewContent += `
      <div class="onereview-scam-warning">
        <strong>SCAM/FRAUD RISK:</strong>
        <p>This website has been reported with a high risk of scam or fraud. We strongly recommend avoiding this website or at least exercising caution and thoroughly researching before making any transactions or sharing any information with this website.</p>
      </div>
    `;
  }

  // Only show AI review if scam score is acceptable or if we have valid review data
  if (website.ai_review && (!website.scam_adviser_score || website.scam_adviser_score >= 80)) {
    try {
      const review = JSON.parse(website.ai_review);
      const activeIssues = Object.entries(review.issues)
        .filter(([_, value]) => (value !== false && !value.description?.includes("INSUFFICIENT_DATA")))
        .map(([key, value]) => {
          const issueValue = typeof value === 'object' ? value : { description: value, impact_for_consumer: 0 };
          return {
            title: formatFieldName(key),
            description: issueValue.description,
            impact: issueValue.impact_for_consumer
          };
        })
        .sort((a, b) => b.impact - a.impact); // Sort by impact (highest first)

      reviewContent += `
        <p class="onereview-overview">${review.overview}</p>
        ${activeIssues.length > 0 ? `
          <h3 class="onereview-issues-title">Potential Issues and Risks</h3>
          <div class="onereview-issues-list">
            ${activeIssues.map(issue => {
              const impactInfo = getSeverityInfo(issue.impact);
              return `
                <div class="onereview-issue-container">
                  <div class="onereview-issue">
                    <div class="onereview-issue-title">
                      ${issue.title}
                      ${impactInfo ? `
                        <span class="onereview-impact-badge ${impactInfo.class}">
                          ${impactInfo.label}
                        </span>
                      ` : ''}
                    </div>
                    <p class="onereview-issue-description">${issue.description}</p>
                  </div>
                </div>
              `;
            }).join('')}
          </div>
        ` : `
          <p class="onereview-no-issues">
            We didn't find any significant issues with this website. However, as with any online service, we recommend exercising general caution and following standard online safety practices.
          </p>
        `}
      `;
    } catch (error) {
      console.error('Error parsing review JSON:', error);
      reviewContent += '<p class="onereview-error">Error displaying review data.</p>';
    }
  } else if (!website.scam_adviser_score || website.scam_adviser_score >= 80) {
    reviewContent += '<p class="onereview-no-review">No detailed review available for this website.</p>';
  }

  // Create overlay element
  const overlay = document.createElement('div');
  overlay.id = 'onereview-overlay';
  overlay.className = `onereview-overlay onereview-${riskLevel.class}`;

  overlay.innerHTML = `
    <div class="onereview-header">
      <div class="onereview-logo">
        <svg xmlns="http://www.w3.org/2000/svg" viewBox="2465 2834.6 1000 1000" width="32px" height="32px" style="margin-right: 8px;">
          <path d="M 3116.74 3218.86 L 3122.1 3277.74 C 3122.33 3280.27 3124.31 3282.17 3126.69 3282.17 L 3197.92 3281.98 C 3200.04 3281.98 3201.88 3283.45 3202.38 3285.64 C 3202.93 3287.82 3202.03 3290.05 3200.18 3291.15 L 3129.85 3332.44 C 3128.2 3333.41 3127.32 3335.19 3127.48 3337.17 L 3134.95 3419.45 C 3135.1 3421.18 3136.03 3422.61 3137.52 3423.36 C 3139 3424.13 3140.63 3424.05 3142 3423.11 L 3442.77 3221.97 C 3444.55 3220.8 3445.35 3218.62 3444.75 3216.49 C 3444.17 3214.36 3442.41 3212.96 3440.31 3212.96 L 3121.34 3213.5 C 3120.02 3213.51 3118.85 3214.05 3117.93 3215.1 C 3117.03 3216.17 3116.62 3217.45 3116.74 3218.86" style="fill: #2563eb; fill-rule: evenodd;"/>
          <path d="M 2813.1 3518.47 L 2764.58 3546.94 C 2762.81 3547.98 2760.68 3547.7 2759.2 3546.24 C 2757.7 3544.76 2757.3 3542.52 2758.18 3540.58 L 2781.28 3489.24 L 2814.48 3415.38 C 2815.37 3413.43 2815 3411.22 2813.52 3409.74 L 2772.76 3368.46 L 2693.41 3288.12 C 2692.04 3286.7 2691.6 3284.64 2692.34 3282.75 C 2693.08 3280.84 2694.75 3279.67 2696.69 3279.71 L 2816.62 3281.71 L 2879.85 3282.75 C 2881.59 3282.79 2883.11 3281.84 2883.95 3280.21 L 2914.54 3221.09 C 2915.34 3219.54 2915.31 3217.78 2914.45 3216.26 C 2913.6 3214.72 2912.17 3213.85 2910.48 3213.86 L 2850.86 3213.96 L 2494.38 3214.57 C 2492.43 3214.57 2490.73 3215.8 2490.06 3217.74 C 2489.39 3219.69 2489.88 3221.78 2491.35 3223.14 L 2730.97 3443.09 C 2732.62 3444.59 2733.04 3447.04 2732.01 3449.08 L 2550.79 3807.63 C 2549.79 3809.63 2550.15 3811.99 2551.73 3813.53 C 2553.27 3815.05 2555.52 3815.27 2557.33 3814.06 L 2888.73 3592.47 C 2890.47 3591.3 2892.64 3591.49 2894.21 3592.92 L 2948.47 3642.72 C 2949.9 3644.05 2951.81 3644.31 2953.49 3643.42 C 2955.19 3642.56 2956.18 3640.79 2956.1 3638.8 C 2955.19 3617.88 2953.88 3588.94 2952.21 3552.02 C 2952.16 3550.73 2951.68 3549.63 2950.78 3548.73 L 2883.78 3480.89 C 2882.29 3479.36 2880.14 3479.06 2878.35 3480.14 L 2813.1 3518.47" style="fill: #2563eb; fill-rule: evenodd;"/>
          <path d="M 3075.77 3213.59 L 3040.56 2857.57 C 3040.34 2855.39 3038.88 2853.69 3036.85 2853.26 C 3034.83 2852.84 3032.86 2853.82 3031.9 2855.76 L 2876.33 3163.54 C 2875.54 3165.09 2875.57 3166.82 2876.43 3168.32 C 2877.26 3169.84 2878.67 3170.71 2880.34 3170.74 L 2948.01 3171.81 C 2950.37 3171.85 2952.29 3173.72 2952.53 3176.19 L 2956.24 3213.78 L 2963.04 3282.59 L 2976.83 3422.3 L 2987.15 3526.68 L 3003.42 3691.42 C 3003.54 3692.7 3004.06 3693.76 3004.98 3694.61 L 3126.36 3806 C 3127.8 3807.33 3129.79 3807.59 3131.5 3806.65 C 3133.21 3805.68 3134.17 3803.83 3133.97 3801.79 L 3099.32 3451.65 L 3089.86 3355.92 L 3082.58 3282.27 L 3075.77 3213.59 Z" style="fill: #14b8a6; fill-rule: evenodd;"/>
        </svg>
        <span>OneReview</span>
      </div>
      <div class="onereview-top-actions">
        <div class="onereview-settings">
          <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M10.325 4.317c.426-1.756 2.924-1.756 3.35 0a1.724 1.724 0 002.573 1.066c1.543-.94 3.31.826 2.37 2.37a1.724 1.724 0 001.065 2.572c1.756.426 1.756 2.924 0 3.35a1.724 1.724 0 00-1.066 2.573c.94 1.543-.826 3.31-2.37 2.37a1.724 1.724 0 00-2.572 1.065c-.426 1.756-2.924 1.756-3.35 0a1.724 1.724 0 00-2.573-1.066c-1.543.94-3.31-.826-2.37-2.37a1.724 1.724 0 00-1.065-2.572c-1.756-.426-1.756-2.924 0-3.35a1.724 1.724 0 001.066-2.573c-.94-1.543.826-3.31 2.37-2.37.996.608 2.296.07 2.572-1.065z" />
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
          </svg>
        </div>
        <div class="onereview-close" onclick="document.getElementById('onereview-overlay').remove()">
          <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12" />
          </svg>
        </div>
      </div>
    </div>
    <div class="onereview-content">
      <div class="onereview-website-info-container">
        <div class="onereview-website-name">${website.domain}</div>
        <div class="onereview-risk-score">
          <div class="onereview-badge"><span class="onereview-${riskLevel.class}">${riskLevel.label}</span></div>
        </div>
      </div>
      <div class="onereview-review">
        ${reviewContent}
      </div>
      ${website.review_sources && website.review_sources.length > 0 && website.total_reviews > 0 ? `
        <div class="onereview-external-reviews">
          <h3 class="onereview-section-title">External Review Sources Analysis</h3>
          <div class="onereview-stats-container">
            <div class="onereview-stat-item">
              <span class="onereview-stat-label">Average Score</span>
              <span class="onereview-stat-value">${((website.rating_distribution[5] * 5 + 
                                                    website.rating_distribution[4] * 4 + 
                                                    website.rating_distribution[3] * 3 + 
                                                    website.rating_distribution[2] * 2 + 
                                                    website.rating_distribution[1]) / 
                                                    Object.values(website.rating_distribution).reduce((a, b) => a + b, 0)).toFixed(1)}</span>
            </div>
            <div class="onereview-stat-item">
              <span class="onereview-stat-label">Total Reviews</span>
              <span class="onereview-stat-value">${website.total_reviews}</span>
            </div>
          </div>
          <div class="onereview-rating-bars">
            ${[5, 4, 3, 2, 1].map(rating => {
              const percentage = (website.rating_distribution[rating] || 0);
              return `
                <div class="onereview-rating-bar-item">
                  <span class="onereview-rating-label">${rating} star</span>
                  <div class="onereview-rating-bar-container">
                    <div class="onereview-rating-bar" style="width: ${percentage}%"></div>
                  </div>
                  <span class="onereview-rating-value">${website.rating_distribution[rating] || 0}%</span>
                </div>
              `;
            }).join('')}
          </div>
          <div class="onereview-external-links">
            ${website.review_sources.includes('trustpilot') ? `
              <a href="https://www.trustpilot.com/review/${website.domain}" 
                 target="_blank" 
                 rel="noopener noreferrer" 
                 class="onereview-external-link onereview-trustpilot">
                View on Trustpilot
              </a>
            ` : ''}
            ${website.review_sources.includes('bbb') ? `
              <a href="https://www.bbb.org/search?find_country=USA&find_text=${website.domain}" 
                 target="_blank" 
                 rel="noopener noreferrer" 
                 class="onereview-external-link onereview-bbb">
                View on BBB
              </a>
            ` : ''}
          </div>
        </div>
      ` : ''}
      <div class="onereview-feedback-section">
        <h3 class="onereview-feedback-title">Was this review helpful?</h3>
        <div class="onereview-feedback-buttons">
          <button class="onereview-feedback-button onereview-helpful" data-website-id="${website.id}" data-helpful="true">Helpful</button>
          <button class="onereview-feedback-button onereview-not-helpful" data-website-id="${website.id}" data-helpful="false">Not Helpful</button>
        </div>
        <div id="onereview-feedback-response"></div>
      </div>
    </div>
    <div class="onereview-actions">
      <button class="onereview-button onereview-button-secondary" id="onereview-dismiss">
        Dismiss
      </button>
      <button class="onereview-button onereview-button-primary" id="onereview-view-report" data-domain="${encodeURIComponent(website.domain)}">
        View Full Report
      </button>
    </div>
  `;

  document.body.appendChild(overlay);

  // Add event listeners after appending the overlay
  const settingsButton = overlay.querySelector('.onereview-settings');
  const helpfulButton = overlay.querySelector('.onereview-helpful');
  const notHelpfulButton = overlay.querySelector('.onereview-not-helpful');
  const dismissButton = overlay.querySelector('#onereview-dismiss');
  const viewReportButton = overlay.querySelector('#onereview-view-report');

  settingsButton.addEventListener('click', () => {
    chrome.runtime.sendMessage({type: 'openSettings'});
  });

  helpfulButton.addEventListener('click', () => {
    const websiteId = parseInt(helpfulButton.dataset.websiteId);
    submitOverlayFeedback(websiteId, true);
  });

  notHelpfulButton.addEventListener('click', () => {
    const websiteId = parseInt(notHelpfulButton.dataset.websiteId);
    submitOverlayFeedback(websiteId, false);
  });

  dismissButton.addEventListener('click', () => {
    document.getElementById('onereview-overlay').remove();
  });

  viewReportButton.addEventListener('click', () => {
    const domain = viewReportButton.dataset.domain;
    openReviewPage(domain);
  });

  // Auto-hide after 15 seconds
  // setTimeout(() => {
  //   removeOverlay();
  // }, 15000);
}

// Function to create and show the floating indicator
function showRiskIndicator(website) {
  // Don't show indicator if risk score is 0 or website is null
  if (!website || website.risk_score === 0) return;

  // Get the indicator threshold setting
  chrome.storage.sync.get(['indicatorThreshold'], (data) => {
    const threshold = data.indicatorThreshold || 40; // Default to Medium Risk
    
    // Only show indicator if risk score is above or equal to the threshold
    if (website.risk_score < threshold) return;

    // Remove any existing indicator
    removeIndicator();

    // Determine risk level
    const riskLevel = getRiskLevel(website.risk_score);
    
    // Get color based on risk level
    const colors = {
      'no-risk': '#22c55e',     // green-500
      'low-risk': '#22c55e',    // lime-500
      'medium-risk': '#eab308',  // yellow-500
      'elevated-risk': '#f97316', // orange-500
      'high-risk': '#ef4444'     // red-500
    };
    
    const color = colors[riskLevel.class];

    // Create indicator element
    const indicator = document.createElement('div');
    indicator.id = 'onereview-indicator';
    indicator.className = 'onereview-indicator';

    // Add click handler to show full overlay
    indicator.onclick = () => showRiskOverlay(website);

    indicator.innerHTML = `
      <div class="onereview-logo">
        <svg xmlns="http://www.w3.org/2000/svg" viewBox="2465 2834.6 1000 1000" width="24px" height="24px">
          <path d="M 3116.74 3218.86 L 3122.1 3277.74 C 3122.33 3280.27 3124.31 3282.17 3126.69 3282.17 L 3197.92 3281.98 C 3200.04 3281.98 3201.88 3283.45 3202.38 3285.64 C 3202.93 3287.82 3202.03 3290.05 3200.18 3291.15 L 3129.85 3332.44 C 3128.2 3333.41 3127.32 3335.19 3127.48 3337.17 L 3134.95 3419.45 C 3135.1 3421.18 3136.03 3422.61 3137.52 3423.36 C 3139 3424.13 3140.63 3424.05 3142 3423.11 L 3442.77 3221.97 C 3444.55 3220.8 3445.35 3218.62 3444.75 3216.49 C 3444.17 3214.36 3442.41 3212.96 3440.31 3212.96 L 3121.34 3213.5 C 3120.02 3213.51 3118.85 3214.05 3117.93 3215.1 C 3117.03 3216.17 3116.62 3217.45 3116.74 3218.86" style="fill: ${color}; fill-rule: evenodd;"/>
          <path d="M 2813.1 3518.47 L 2764.58 3546.94 C 2762.81 3547.98 2760.68 3547.7 2759.2 3546.24 C 2757.7 3544.76 2757.3 3542.52 2758.18 3540.58 L 2781.28 3489.24 L 2814.48 3415.38 C 2815.37 3413.43 2815 3411.22 2813.52 3409.74 L 2772.76 3368.46 L 2693.41 3288.12 C 2692.04 3286.7 2691.6 3284.64 2692.34 3282.75 C 2693.08 3280.84 2694.75 3279.67 2696.69 3279.71 L 2816.62 3281.71 L 2879.85 3282.75 C 2881.59 3282.79 2883.11 3281.84 2883.95 3280.21 L 2914.54 3221.09 C 2915.34 3219.54 2915.31 3217.78 2914.45 3216.26 C 2913.6 3214.72 2912.17 3213.85 2910.48 3213.86 L 2850.86 3213.96 L 2494.38 3214.57 C 2492.43 3214.57 2490.73 3215.8 2490.06 3217.74 C 2489.39 3219.69 2489.88 3221.78 2491.35 3223.14 L 2730.97 3443.09 C 2732.62 3444.59 2733.04 3447.04 2732.01 3449.08 L 2550.79 3807.63 C 2549.79 3809.63 2550.15 3811.99 2551.73 3813.53 C 2553.27 3815.05 2555.52 3815.27 2557.33 3814.06 L 2888.73 3592.47 C 2890.47 3591.3 2892.64 3591.49 2894.21 3592.92 L 2948.47 3642.72 C 2949.9 3644.05 2951.81 3644.31 2953.49 3643.42 C 2955.19 3642.56 2956.18 3640.79 2956.1 3638.8 C 2955.19 3617.88 2953.88 3588.94 2952.21 3552.02 C 2952.16 3550.73 2951.68 3549.63 2950.78 3548.73 L 2883.78 3480.89 C 2882.29 3479.36 2880.14 3479.06 2878.35 3480.14 L 2813.1 3518.47" style="fill: ${color}; fill-rule: evenodd;"/>
          <path d="M 3075.77 3213.59 L 3040.56 2857.57 C 3040.34 2855.39 3038.88 2853.69 3036.85 2853.26 C 3034.83 2852.84 3032.86 2853.82 3031.9 2855.76 L 2876.33 3163.54 C 2875.54 3165.09 2875.57 3166.82 2876.43 3168.32 C 2877.26 3169.84 2878.67 3170.71 2880.34 3170.74 L 2948.01 3171.81 C 2950.37 3171.85 2952.29 3173.72 2952.53 3176.19 L 2956.24 3213.78 L 2963.04 3282.59 L 2976.83 3422.3 L 2987.15 3526.68 L 3003.42 3691.42 C 3003.54 3692.7 3004.06 3693.76 3004.98 3694.61 L 3126.36 3806 C 3127.8 3807.33 3129.79 3807.59 3131.5 3806.65 C 3133.21 3805.68 3134.17 3803.83 3133.97 3801.79 L 3099.32 3451.65 L 3089.86 3355.92 L 3082.58 3282.27 L 3075.77 3213.59 Z" style="fill: ${color}; fill-rule: evenodd;"/>
        </svg>
      </div>
    `;

    document.body.appendChild(indicator);
  });
}

// Function to remove existing overlay
function removeOverlay() {
  const existingOverlay = document.getElementById('onereview-overlay');
  if (existingOverlay) {
    existingOverlay.remove();
  }
}

// Function to remove existing indicator
function removeIndicator() {
  const existingIndicator = document.getElementById('onereview-indicator');
  if (existingIndicator) {
    existingIndicator.remove();
  }
}

// Function to determine risk level
function getRiskLevel(score) {
  if (score >= 80) return { label: 'No Trust', class: 'high-risk' };
  if (score >= 60) return { label: 'Low Trust', class: 'elevated-risk' };
  if (score >= 40) return { label: 'Moderate Trust', class: 'medium-risk' };
  if (score >= 20) return { label: 'High Trust', class: 'low-risk' };
  return { label: 'Very High Trust', class: 'no-risk' };
}

// Helper function to format field names
function formatFieldName(key) {
  return key
    .split('_')
    .map(word => word.charAt(0).toUpperCase() + word.slice(1))
    .join(' ');
}

// Add message listener for background script communication
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (!request.type || !request.website) return;

  // Only handle messages from the extension itself
  if (!sender.id || sender.id !== chrome.runtime.id) return;

  switch (request.type) {
    case 'showRiskAlert':
      showRiskOverlay(request.website);
      break;
    case 'showRiskIndicator':
      showRiskIndicator(request.website);
      break;
  }
});

// Add these functions after the formatFieldName function
async function submitOverlayFeedback(websiteId, isHelpful) {
  try {
    const response = await fetch(`${WEBAPP_URL}/api/websites/feedback`, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        website_id: websiteId,
        is_helpful: isHelpful
      })
    });

    if (!response.ok) {
      throw new Error('Failed to submit feedback');
    }

    const feedbackResponse = document.getElementById('onereview-feedback-response');
    
    if (isHelpful) {
      feedbackResponse.innerHTML = `
        <div class="onereview-feedback-thank-you">
          <p>Thank you! Please donate a cup of coffee to our small non-commercial project.</p>
          <a href="https://buymeacoffee.com/onereview" 
             target="_blank" 
             class="onereview-donate-button">
            Buy us a coffee ☕
          </a>
        </div>
      `;
    } else {
      feedbackResponse.innerHTML = `
        <div class="onereview-feedback-explanation">
          <p>Could you please tell us why this review wasn't helpful?</p>
          <textarea 
            class="onereview-feedback-textarea" 
            placeholder="Your feedback will help us improve..."
            rows="3"
          ></textarea>
          <div class="onereview-feedback-actions">
            <button class="onereview-submit-feedback" data-website-id="${websiteId}">Submit</button>
            <button class="onereview-cancel-feedback">Cancel</button>
          </div>
        </div>
      `;

      // Add event listeners for the new buttons
      const submitButton = feedbackResponse.querySelector('.onereview-submit-feedback');
      const cancelButton = feedbackResponse.querySelector('.onereview-cancel-feedback');

      submitButton.addEventListener('click', () => {
        const websiteId = parseInt(submitButton.dataset.websiteId);
        submitOverlayExplanation(websiteId);
      });

      cancelButton.addEventListener('click', hideOverlayFeedbackForm);
    }

    // Hide the feedback buttons
    const feedbackButtons = document.querySelector('.onereview-feedback-buttons');
    feedbackButtons.style.display = 'none';

  } catch (error) {
    console.error('Error submitting feedback:', error);
    const feedbackResponse = document.getElementById('onereview-feedback-response');
    feedbackResponse.innerHTML = `
      <p class="onereview-error">Error submitting feedback. Please try again later.</p>
    `;
  }
}

// Make the function available globally
window.submitOverlayFeedback = submitOverlayFeedback;
window.submitOverlayExplanation = submitOverlayExplanation;
window.hideOverlayFeedbackForm = hideOverlayFeedbackForm;

async function submitOverlayExplanation(websiteId) {
  const textarea = document.querySelector('.onereview-feedback-textarea');
  const explanation = textarea.value.trim();
  
  if (!explanation) return;

  try {
    const response = await fetch(`${WEBAPP_URL}/api/websites/feedback`, {
      method: 'PATCH',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        website_id: websiteId,
        explanation: explanation
      })
    });

    if (!response.ok) {
      throw new Error('Failed to submit explanation');
    }

    const feedbackResponse = document.getElementById('onereview-feedback-response');
    feedbackResponse.innerHTML = `
      <p class="onereview-feedback-thank-you">Thank you for your feedback!</p>
    `;

  } catch (error) {
    console.error('Error submitting explanation:', error);
    const feedbackResponse = document.getElementById('onereview-feedback-response');
    feedbackResponse.innerHTML = `
      <p class="onereview-error">Error submitting explanation. Please try again later.</p>
    `;
  }
}

function hideOverlayFeedbackForm() {
  const feedbackResponse = document.getElementById('onereview-feedback-response');
  feedbackResponse.innerHTML = `
    <p class="onereview-feedback-thank-you">Thank you for your feedback!</p>
  `;
}

function openReviewPage(domain) {
  window.open(`${WEBAPP_URL}/review/${domain}`, '_blank');
}

async function submitFeedback(domain, feedback) {
  try {
    const response = await fetch(`${WEBAPP_URL}/api/websites/feedback`, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        domain,
        feedback
      })
    });

    if (!response.ok) {
      throw new Error('Failed to submit feedback');
    }

    return await response.json();
  } catch (error) {
    console.error('Error submitting feedback:', error);
    return null;
  }
}

function getSeverityInfo(impact) {
  switch(impact) {
    case 3: return { label: 'High Impact', class: 'onereview-impact-3' };
    case 2: return { label: 'Medium Impact', class: 'onereview-impact-2' };
    case 1: return { label: 'Low Impact', class: 'onereview-impact-1' };
    default: return null;
  }
} 