const API_URL = 'https://onereview.org/api/websites';
const WEBAPP_URL = 'https://onereview.org';

// Risk level thresholds
const RISK_LEVELS = {
  NO_TRUST: 80,
  LOW_TRUST: 60,
  MODERATE_TRUST: 40,
  HIGH_TRUST: 20
};

// Severity impact levels
const SEVERITY = {
  HIGH: 3,
  MEDIUM: 2,
  LOW: 1
};

// Risk level configurations
function getTrustLevel(score) {
  if (score >= RISK_LEVELS.NO_TRUST) return { label: 'No Trust', hex: '#ef4444' };
  if (score >= RISK_LEVELS.LOW_TRUST) return { label: 'Low Trust', hex: '#e86800' };
  if (score >= RISK_LEVELS.MODERATE_TRUST) return { label: 'Moderate Trust', hex: '#eab308' };
  if (score >= RISK_LEVELS.HIGH_TRUST) return { label: 'High Trust', hex: '#22c55e' };
  return { label: 'Very High Trust', hex: '#22c55e' };
}

function getSeverityInfo(impact) {
  switch(impact) {
    case SEVERITY.HIGH: return { label: 'High Impact', class: 'impact-3' };
    case SEVERITY.MEDIUM: return { label: 'Medium Impact', class: 'impact-2' };
    case SEVERITY.LOW: return { label: 'Low Impact', class: 'impact-1' };
    default: return null;
  }
}

// Function to extract domain from URL
function extractDomain(url) {
  if (!url) return null;
  try {
    const urlObj = new URL(url);
    return urlObj.hostname.replace(/^www\./, '');
  } catch (e) {
    console.error('Error extracting domain:', e);
    return null;
  }
}

function formatFieldName(key) {
  return key
    .split('_')
    .map(word => word.charAt(0).toUpperCase() + word.slice(1))
    .join(' ');
}

// Function to fetch website data
async function fetchWebsiteData(domain) {
  if (!domain) return;

  try {
    const url = new URL(API_URL);
    url.searchParams.append('query', encodeURIComponent(domain));

    const response = await fetch(url);
    if (!response.ok) {
      throw new Error(`HTTP error! status: ${response.status}`);
    }
    const result = await response.json();
    return result.data?.[0] || null;
  } catch (error) {
    console.error('Error fetching website data:', error);
    return null;
  }
}

async function submitFeedback(websiteId, isHelpful, explanation = null) {
  if (!websiteId) {
    throw new Error('Website ID is required');
  }

  try {
    const response = await fetch(`${API_URL}/feedback`, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ website_id: websiteId, is_helpful: isHelpful, explanation })
    });

    if (!response.ok) {
      const error = await response.json();
      throw new Error(error.error || 'Failed to submit feedback');
    }

    return (await response.json()).data;
  } catch (error) {
    console.error('Error submitting feedback:', error);
    throw error;
  }
}

async function updateFeedbackExplanation(feedbackId, explanation) {
  if (!feedbackId || !explanation?.trim()) {
    throw new Error('Feedback ID and explanation are required');
  }

  try {
    const response = await fetch(`${API_URL}/feedback`, {
      method: 'PATCH',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ feedback_id: feedbackId, explanation })
    });

    if (!response.ok) {
      const error = await response.json();
      throw new Error(error.error || 'Failed to update feedback');
    }

    return true;
  } catch (error) {
    console.error('Error updating feedback:', error);
    throw error;
  }
}

// Function to update popup content
function updatePopupContent(website) {
  const contentDiv = document.getElementById('content');
  const loadingDiv = document.getElementById('loading');

  if (!website) {
    contentDiv.innerHTML = `
      <div class="error-message">
        <p>No data available for this website.</p>
        <p>Please try again later.</p>
      </div>
    `;
    if (loadingDiv) {
      loadingDiv.style.display = 'none';
    }
    return;
  }

  const riskInfo = getTrustLevel(website.risk_score);
  let reviewContent = '';

  // Add scam risk warning if applicable
  if (website.scam_adviser_score && website.scam_adviser_score < RISK_LEVELS.NO_TRUST) {
    reviewContent += renderScamWarning();
  }

  // Add AI review content
  if (website.ai_review && (!website.scam_adviser_score || website.scam_adviser_score >= RISK_LEVELS.NO_TRUST)) {
    reviewContent += renderAIReview(website.ai_review);
  } else if (!website.scam_adviser_score || website.scam_adviser_score >= RISK_LEVELS.NO_TRUST) {
    reviewContent += '<p class="no-review">No detailed review available for this website.</p>';
  }

  contentDiv.innerHTML = `
    <div class="website-info">
      <div class="website-header">
        <h2 class="website-name">${website.domain}</h2>
        <span class="risk-badge" style="background-color: ${riskInfo.hex}">
          ${riskInfo.label}
        </span>
      </div>
      
      <div class="summary">
        <h3>Review</h3>
        <div class="review-content">
          ${reviewContent}
        </div>
      </div>

      ${renderExternalReviews(website)}

      <div id="feedback-container"></div>

      <div class="actions">
        <button id="viewReportButton" class="button button-primary">
          View Full Report
        </button>
      </div>
    </div>
  `;

  // Add event listener for view report button
  const viewReportButton = document.getElementById('viewReportButton');
  viewReportButton.addEventListener('click', () => {
    chrome.tabs.create({ url: `${WEBAPP_URL}/review/${encodeURIComponent(website.domain)}` });
  });

  // Add feedback section
  const feedbackContainer = document.getElementById('feedback-container');
  feedbackContainer.appendChild(renderFeedbackSection(website.id));

  if (loadingDiv) {
    loadingDiv.style.display = 'none';
  }
}

// Function to determine risk level
function getRiskLevel(score) {
  if (score >= 80) return { label: 'No Trust', class: 'high-risk' };
  if (score >= 60) return { label: 'Low Trust', class: 'elevated-risk' };
  if (score >= 40) return { label: 'Moderate Trust', class: 'medium-risk' };
  if (score >= 20) return { label: 'High Trust', class: 'low-risk' };
  return { label: 'Very High Trust', class: 'no-risk' };
}

// Function to get risk color
function getRiskColor(riskClass) {
  const colors = {
    'no-risk': '#22c55e',     // green-500
    'low-risk': '#22c55e',    // lime-500
    'medium-risk': '#eab308',  // yellow-500
    'elevated-risk': '#f97316', // orange-500
    'high-risk': '#ef4444'     // red-500
  };
  return colors[riskClass] || colors['no-risk'];
}

function renderError(message) {
  document.getElementById('content').innerHTML = `
    <div class="not-found">
      <h2>Website Not Found</h2>
      <p>${message}</p>
    </div>
  `;
}

function renderScamWarning() {
  return `
    <div class="scam-warning">
      <strong>SCAM/FRAUD RISK:</strong>
      <p>This website has been reported with a high risk of scam or fraud. We strongly recommend avoiding this website or at least exercising caution and thoroughly researching before making any transactions or sharing any information with this website.</p>
    </div>
  `;
}

function renderAIReview(aiReview) {
  try {
    const review = JSON.parse(aiReview);
    const activeIssues = Object.entries(review.issues)
      // Filter out false values and insufficient data
      .filter(([_, value]) => (value !== false && value !== "false" && !value?.description?.includes("INSUFFICIENT_DATA")))
      .map(([key, value]) => {
        // Handle both string and object values
        const issueValue = typeof value === 'string' 
          ? { description: value, impact_for_consumer: 1 } // Default to low impact for string values
          : value;
        
        return {
          title: formatFieldName(key),
          description: issueValue.description,
          impact: issueValue.impact_for_consumer || 0 // Ensure we have a default value
        };
      })
      .sort((a, b) => b.impact - a.impact);

    return `
      <p class="overview">${review.overview}</p>
      ${activeIssues.length > 0 ? `
        <h3 class="issues-title">Potential Issues and Risks</h3>
        <div class="issues-list">
          ${activeIssues.map(issue => {
            const severityInfo = getSeverityInfo(issue.impact);
            return `
              <div class="issue-container">
                <div class="issue">
                  <div class="issue-title">
                    ${issue.title}
                    ${severityInfo ? `
                      <span class="severity-badge ${severityInfo.class}">
                        ${severityInfo.label}
                      </span>
                    ` : ''}
                  </div>
                  <p class="issue-description">${issue.description}</p>
                </div>
              </div>
            `;
          }).join('')}
        </div>
      ` : `
        <p class="no-issues">
          We didn't find any significant issues with this website. However, as with any online service, we recommend exercising general caution and following standard online safety practices.
        </p>
      `}
    `;
  } catch (error) {
    console.error('Error parsing review JSON:', error);
    return '<p class="error">Error displaying review data.</p>';
  }
}

function renderExternalReviews(website) {
  if (!website.review_sources?.length || !website.total_reviews) return '';

  const averageScore = ((website.rating_distribution[5] * 5 + 
                        website.rating_distribution[4] * 4 + 
                        website.rating_distribution[3] * 3 + 
                        website.rating_distribution[2] * 2 + 
                        website.rating_distribution[1]) / 
                        Object.values(website.rating_distribution).reduce((a, b) => a + b, 0)).toFixed(1);

  return `
    <div class="external-reviews">
      <h3 class="section-title">External Review Sources Analysis</h3>
      <div class="stats-container">
        <div class="stat-item">
          <span class="stat-label">Average Score</span>
          <span class="stat-value">${averageScore}</span>
        </div>
        <div class="stat-item">
          <span class="stat-label">Total Reviews</span>
          <span class="stat-value">${website.total_reviews}</span>
        </div>
      </div>
      <div class="rating-bars">
        ${[5, 4, 3, 2, 1].map(rating => {
          const percentage = (website.rating_distribution[rating] || 0);
          return `
            <div class="rating-bar-item">
              <span class="rating-label">${rating} star</span>
              <div class="rating-bar-container">
                <div class="rating-bar" style="width: ${percentage}%"></div>
              </div>
              <span class="rating-value">${percentage}%</span>
            </div>
          `;
        }).join('')}
      </div>
      <div class="external-links">
        ${website.review_sources.includes('trustpilot') ? `
          <a href="https://www.trustpilot.com/review/${website.domain}" 
             target="_blank" 
             rel="noopener noreferrer" 
             class="external-link trustpilot">
            View on Trustpilot
          </a>
        ` : ''}
        ${website.review_sources.includes('bbb') ? `
          <a href="https://www.bbb.org/search?find_country=USA&find_text=${website.domain}" 
             target="_blank" 
             rel="noopener noreferrer" 
             class="external-link bbb">
            View on BBB
          </a>
        ` : ''}
      </div>
    </div>
  `;
}

function renderWebsiteInfo(website, liveChecksEnabled) {
  if (!website) return;

  if (website.is_processing) {
    console.log('Website is processing, checking status again');
    return fetchWebsiteData(website.domain);
  }

  const riskInfo = getTrustLevel(website.risk_score);
  let reviewContent = '';

  // Add scam risk warning if applicable
  if (website.scam_adviser_score && website.scam_adviser_score < RISK_LEVELS.NO_TRUST) {
    reviewContent += renderScamWarning();
  }

  // Add AI review content
  if (website.ai_review && (!website.scam_adviser_score || website.scam_adviser_score >= RISK_LEVELS.NO_TRUST)) {
    reviewContent += renderAIReview(website.ai_review);
  } else if (!website.scam_adviser_score || website.scam_adviser_score >= RISK_LEVELS.NO_TRUST) {
    reviewContent += '<p class="no-review">No detailed review available for this website.</p>';
  }

  const content = document.getElementById('content');
  content.innerHTML = `
    ${!liveChecksEnabled ? `
      <div class="live-checks-disabled visible">
        Live checks are disabled. Data may not be up to date.
      </div>
    ` : ''}
    <div class="website-info">
      <div class="website-header">
        <h2 class="website-name">${website.domain}</h2>
        <span class="risk-badge" style="background-color: ${riskInfo.hex}">
          ${riskInfo.label}
        </span>
      </div>
      
      <div class="summary">
        <h3>Review</h3>
        <div class="review-content">
          ${reviewContent}
        </div>
      </div>

      ${renderExternalReviews(website)}

      <div id="feedback-container"></div>

      <div class="actions">
        <a href="${WEBAPP_URL}/review/${encodeURIComponent(website.domain)}" 
           target="_blank" 
           class="button button-primary">
          View Report
        </a>
      </div>
    </div>
  `;

  // Add feedback section
  const feedbackContainer = document.getElementById('feedback-container');
  feedbackContainer.appendChild(renderFeedbackSection(website.id));
}

function renderFeedbackSection(websiteId) {
  const feedbackSection = document.createElement('div');
  feedbackSection.className = 'feedback-section';
  feedbackSection.innerHTML = `
    <h3 class="feedback-title">Was this review helpful?</h3>
    <div class="feedback-buttons">
      <button class="feedback-button helpful">Helpful</button>
      <button class="feedback-button not-helpful">Not Helpful</button>
    </div>
  `;

  const helpfulBtn = feedbackSection.querySelector('.helpful');
  const notHelpfulBtn = feedbackSection.querySelector('.not-helpful');

  helpfulBtn.addEventListener('click', async () => {
    try {
      const feedback = await submitFeedback(websiteId, true);
      if (feedback) {
        feedbackSection.innerHTML = `
          <div class="feedback-thank-you">
            <p>Thank you! Please donate a cup of coffee to our small non-commercial project.</p>
            <a href="https://buymeacoffee.com/onereview" 
               target="_blank" 
               class="donate-button">
              Buy us a coffee ☕
            </a>
          </div>
        `;
      }
    } catch (error) {
      feedbackSection.innerHTML = `
        <p class="error">Failed to submit feedback. Please try again later.</p>
      `;
    }
  });

  notHelpfulBtn.addEventListener('click', async () => {
    try {
      const feedback = await submitFeedback(websiteId, false);
      if (!feedback) return;

      feedbackSection.innerHTML = `
        <div class="feedback-explanation">
          <p>Could you please tell us why this review wasn't helpful?</p>
          <textarea 
            class="feedback-textarea" 
            placeholder="Your feedback will help us improve..."
            rows="3"
          ></textarea>
          <div class="feedback-actions">
            <button class="submit-feedback">Submit</button>
            <button class="cancel-feedback">Cancel</button>
          </div>
        </div>
      `;

      const submitBtn = feedbackSection.querySelector('.submit-feedback');
      const cancelBtn = feedbackSection.querySelector('.cancel-feedback');
      const textarea = feedbackSection.querySelector('.feedback-textarea');

      submitBtn.addEventListener('click', async () => {
        const explanation = textarea.value.trim();
        if (explanation) {
          try {
            const success = await updateFeedbackExplanation(feedback.id, explanation);
            if (success) {
              feedbackSection.innerHTML = `
                <p class="feedback-thank-you">Thank you for your feedback!</p>
              `;
            }
          } catch (error) {
            feedbackSection.innerHTML = `
              <p class="error">Failed to submit explanation. Please try again later.</p>
            `;
          }
        }
      });

      cancelBtn.addEventListener('click', () => {
        feedbackSection.innerHTML = `
          <p class="feedback-thank-you">Thank you for your feedback!</p>
        `;
      });
    } catch (error) {
      feedbackSection.innerHTML = `
        <p class="error">Failed to submit feedback. Please try again later.</p>
      `;
    }
  });

  return feedbackSection;
}

// Initialize popup
async function initializePopup() {
  try {
    // Get the active tab
    const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });
    if (!tab?.url) {
      throw new Error('No active tab URL found');
    }

    const domain = extractDomain(tab.url);
    if (!domain) {
      throw new Error('Could not extract domain from URL');
    }

    const website = await fetchWebsiteData(domain);
    
    const settings = await chrome.storage.sync.get(['enableLiveChecks']);
    const liveChecksEnabled = settings.enableLiveChecks !== false;
    
    updatePopupContent(website);

    // Send message to check current tab
    chrome.runtime.sendMessage({ type: 'checkCurrentTab' });
  } catch (error) {
    console.error('Error initializing popup:', error);
    updatePopupContent(null);
  }
}

// Event Listeners
document.addEventListener('DOMContentLoaded', () => {
  // Add settings button handler
  document.getElementById('settings-button')?.addEventListener('click', () => {
    chrome.runtime.openOptionsPage();
  });

  // Initialize popup
  initializePopup();
}); 